4.22. umbra.components.factory.scriptEditor.views — Umbra 1.0.9 documentation

# 4.22. umbra.components.factory.scriptEditor.views

views.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Views.

Others:

## 4.22.1. Module Attributes

`umbra.components.factory.scriptEditor.views.` `LOGGER`

## 4.22.2. Classes

class `umbra.components.factory.scriptEditor.views.` `SearchResults_QTreeView`(parent, model=None, readOnly=False, message=None)

  Bases: `umbra.ui.views.Abstract_QTreeView`

  Defines the view for Database Ibl Sets columns.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. readOnly (bool) – View is read only. message (unicode) – View default message when Model is empty.

  `treeViewIndentation`

    Property for self.__treeViewIndentation attribute.

    Returns: | self.__treeViewIndentation.
    Return type: | int

class `umbra.components.factory.scriptEditor.views.` `ScriptEditor_QTabWidget`(parent)

  Bases: `PyQt4.QtGui.QTabWidget`

  Defines a QTabWidget subclass used to display `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` editors.
  It provides support for drag’n’drop by reimplementing relevant methods.

  Initializes the class.

  Parameters: | parent (QObject) – Parent object.

  `contentDropped`

    This signal is emited by the `ScriptEditor_QTabWidget` class when it receives dropped content. ( pyqtSignal )

    Returns: | Event.
    Return type: | QEvent

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `dragEnterEvent`(event)

    Reimplements the `QTabWidget.dragEnterEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `dragMoveEvent`(event)

    Reimplements the `QTabWidget.dragMoveEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `dropEvent`(event)

    Reimplements the `QTabWidget.dropEvent()` method.

    Parameters: | event (QEvent) – QEvent.